﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using System.Threading;
using AR.Amplifier;

namespace Amplifier_Driver_Example
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();

            // Set some defaults to show format
            txt_VisaResourceName.Text = "GPIB0::4::INSTR";
            num_RF_Gain.Value = 50;
            chk_PowerOn.CheckState = CheckState.Checked;
            chk_RF_On.CheckState = CheckState.Checked;

            // Modify the path where the amplifier driver was installed and call GetValidModels
            // to get a list of supported Amplifier models
            string[] strModels = new string[200];
            Amplifier amp = new Amplifier();

            // Fill in model list
            strModels = amp.GetValidModels();
            lst_AmplifierModel.Items.Add("LCD Touch Panel");
            lst_AmplifierModel.Text = "LCD Touch Panel";
            for (int i = 0; i < strModels.Length; i++)
            {
                lst_AmplifierModel.Items.Add(strModels[i]);
            }
        }

        private void RunDriver_Click(object sender, EventArgs e)
        {
            // Initialize the Driver and open the VISA sesson to the amplifier
            // if using RS-232, set the parameters for Serial control in the Initialize
            // function (look at AmplifierDriver.h for format).

            Cursor = Cursors.WaitCursor;
            
            Amplifier amp = new Amplifier(lst_AmplifierModel.Text);
            String VisaResourceName = txt_VisaResourceName.Text;

            amp.Initialize(VisaResourceName);
            Thread.Sleep(100);
            txt_identity.Text = amp.QueryID();

            // Set the Gain
            amp.ConfigureRFGain((uint)num_RF_Gain.Value);
            Thread.Sleep(100);

            // Turn the power on or off.  Note: some amplifiers require more time after
            // powering on before other commands can be sent
            if (chk_PowerOn.CheckState == CheckState.Checked)
            {
                amp.Power(true);
                Thread.Sleep(2000);
            }
            else
                amp.Power(false);

            //Turn the RF on or off
            // In this example the RF will only be enabled
            // if the power is turned on
            if (chk_PowerOn.CheckState == CheckState.Checked && chk_RF_On.CheckState == CheckState.Checked)
                amp.RF_Output(true);
            else
                amp.RF_Output(false);
            Thread.Sleep(100);

            // Read the status of the amplifier.
            // Refer to the manual for tables showing possible values
            // and their meaning for the fault and state commands
            int state = amp.ReadState();
            Thread.Sleep(100);
            txt_State.Text = state.ToString("X");

            int fault = amp.ReadFault();
            Thread.Sleep(100);
            txt_Fault.Text = fault.ToString("X");

            // Read the forward and reverse power if no faults were reported
            double ForwardPower = 0.0;
            double ReversePower = 0.0;
            if (fault == 0)
            {
                ForwardPower = amp.QueryForwardPower();
                ReversePower = amp.QueryReversePower();
            }

            txt_Forward_Power.Text = ForwardPower.ToString();
            txt_Reverse_Power.Text = ReversePower.ToString();

            // Close communication with the amplifier
            amp.Close();

            Cursor = Cursors.Default;
        }

    }
}
