﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using AR.FieldProbe;

namespace Field_Analyzer_Example
{
    public partial class Form1 : Form
    {
        FieldAnalyzer fa;
        public Form1()
        {
            InitializeComponent();

            // Set the datasource of the Units combobox to the Units enumerator
            cbUnits.DataSource = Enum.GetValues(typeof(Units));

            // Create a new instance of a FieldMonitor object
            fa = new FieldAnalyzer();
        }

        private void btnInitialize_Click(object sender, EventArgs e)
        {
            // Try to close a previous session before opening a new one
            try
            {
                fa.Close();
            }
            catch (NullReferenceException) { }

            try
            {
                Cursor.Current = Cursors.WaitCursor;

                // Initialize a new session
                if (fa.Initialize(txtAddress.Text, false) == 0)
                {
                    // Query the attached probe
                    ProbeID probe = fa.QueryProbeID();

                    // Parse the ProbeID struct and display information about the probe
                    txtModel.Text = probe.model;
                    txtSerial.Text = probe.serial;
                    txtFirmware.Text = probe.firmware;

                    // Set the units
                    fa.ConfigureUnits((Units)cbUnits.SelectedItem);

                    // Set the trigger to free run
                    fa.ConfigureTriggerMode(TriggerMode.FREERUN);

                    // Configure the time base
                    fa.ConfigureTimeBase((int)numTimeBase.Value);
                }
            }
            catch (Ivi.Visa.NativeVisaException)
            {
                MessageBox.Show("Error initializing. Check the VISA address and try again.");
            }
        }

        private void btnRead_Click(object sender, EventArgs e)
        {
            // Read the composite field value from the FA
            txtC.Text =string.Format("{0:0.00}", fa.ReadCompositeField());

            // Check the status
            Status sta = fa.QueryStatus();

            chkFault.Checked = sta.fault;
            chkLaser.Checked = sta.laser;
            chkKeyPosition.Checked = sta.keyPosition;
            chkTriggered.Checked = sta.triggered;
            chkWebActive.Checked = sta.webActive;
            chkSyncError.Checked = sta.syncError;
            chkCommError.Checked = sta.internalCommError;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                // Close the session to the FA
                fa.Close();
            }
            catch { }
        }
    }
}
