﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using AR.FieldProbe;

namespace Field_Monitor_Example
{
    public partial class Form1 : Form
    {
        FieldMonitor fm;
        public Form1()
        {
            InitializeComponent();

            // Create a new instance of a FieldMonitor object
            fm = new FieldMonitor();
        }

        private void btnInitialize_Click(object sender, EventArgs e)
        {
            // Try to close a previous session before opening a new one
            try
            {
                fm.Close();
            }
            catch (NullReferenceException) { }

            try
            {
                Cursor.Current = Cursors.WaitCursor;

                // Initialize a new session
                if (fm.Initialize(txtAddress.Text, false) == 0)
                {
                    // Set the display mode to XYZ
                    fm.ConfigureDisplayMode(DisplayMode.XYZ);

                    // Enable the selected channel
                    fm.ConfigureChannelState((int)numChannel.Value, true);

                    // Query the attached probe
                    ProbeID probe = fm.QueryProbeStatus((int)numChannel.Value);

                    // Parse the ProbeID struct and display information about the probe
                    txtModel.Text = probe.model;
                    txtSerial.Text = probe.serial;
                    txtFirmware.Text = probe.firmware;

                    // Configure the axes used for the composite calculation
                    fm.ConfigureAxes((int)numChannel.Value, chkX.Checked, chkY.Checked, chkZ.Checked);

                    // Configure internal correction with the specified frequency
                    fm.ConfigureFrequencyCorrection(false);
                    fm.SetFrequency((double)numFrequency.Value * 1e6);
                }
            }
            catch (Ivi.Visa.NativeVisaException)
            {
                MessageBox.Show("Error initializing. Check the VISA address and try again.");
            }
        }

        private void btnRead_Click(object sender, EventArgs e)
        {
            // Read data from the FM and store it in a ProbeData object
            ProbeData data = fm.ReadData((int)numChannel.Value);

            // Parse the data and display it
            txtX.Text = string.Format("{0:0.00}", data.x);
            txtY.Text = string.Format("{0:0.00}", data.y);
            txtZ.Text = string.Format("{0:0.00}", data.z);
            txtC.Text = string.Format("{0:0.00}", data.c);
            chkStatusOK.Checked = data.statusOK;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                // Return to local mode
                fm.LocalMode();

                // Close the session to the FM
                fm.Close();
            }
            catch { }
        }
    }
}
