﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using AR.FieldProbe;

namespace Field_Probe_Example
{
    public partial class Form1 : Form
    {
        FieldProbe fl;
        public Form1()
        {
            InitializeComponent();

            // Create a new instance of a FieldProbe object
            fl = new FieldProbe();
        }

        private void btnInitialize_Click(object sender, EventArgs e)
        {
            // Try to close a previous session before opening a new one
            try
            {
                fl.Close();
            }
            catch (NullReferenceException) { }

            try
            {
                Cursor.Current = Cursors.WaitCursor;

                // Initialize a new session
                if (fl.Initialize(txtAddress.Text) == 0)
                {
                    // Query the attached probe
                    ProbeID probe = fl.QueryProbeID();

                    // Parse the ProbeID struct and display information about the probe
                    txtModel.Text = probe.model;
                    txtSerial.Text = probe.serial;
                    txtFirmware.Text = probe.firmware;
                    txtLinearization.Text = probe.linearization;
                }
            }
            catch (Ivi.Visa.NativeVisaException)
            {
                MessageBox.Show("Error initializing. Check the VISA address and try again.");
            }
        }
        private void btnRead_Click(object sender, EventArgs e)
        {
            // Read data from the probe and store it in a ProbeData object
            ProbeData data = fl.ReadData();

            // Parse the data and display it
            txtX.Text = string.Format("{0:0.00}", data.x);
            txtY.Text = string.Format("{0:0.00}", data.y);
            txtZ.Text = string.Format("{0:0.00}", data.z);
            txtC.Text = string.Format("{0:0.00}", data.c);
            chkStatusOK.Checked = data.statusOK;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                // Close the session to the probe
                fl.Close();
            }
            catch { }
        }
    }
}
