﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Forms;
using AR.SystemController;

namespace SC1000_Example
{
    public partial class Form1 : Form
    {
        SC1000 sc;
        public Form1()
        {
            InitializeComponent();

            // Create a new instance of an SC2000 object
            sc = new SC1000();
        }

        private void btnInitialize_Click(object sender, EventArgs e)
        {
            // Try to close a previous session before opening a new one
            try
            {
                sc.Close();
            }
            catch (NullReferenceException) { }

            try
            {
                Cursor.Current = Cursors.WaitCursor;

                // Initialize a new session
                if (sc.Initialize(txtAddress.Text) == 0)
                {
                    btnSetAll.Enabled = true;

                    // Query the current state of the switches
                    numSw1.Value = sc.QuerySwitch(1);
                    numSw2.Value = sc.QuerySwitch(2);
                    numSw3.Value = sc.QuerySwitch(3);
                    numSw4.Value = sc.QuerySwitch(4);

                    // Query the current state of the open collector outputs
                    chkOC1.Checked = sc.QueryOpenCollector(1);
                    chkOC2.Checked = sc.QueryOpenCollector(2);
                    chkOC3.Checked = sc.QueryOpenCollector(3);
                    chkOC4.Checked = sc.QueryOpenCollector(4);

                    // Query the current state of the 12V trigger
                    chk12V.Checked = sc.Query12V();
                }
            }
            catch (Ivi.Visa.NativeVisaException)
            {
                // Disable buttons when there is an error initializing
                btnSetAll.Enabled = false;
                MessageBox.Show("Error initializing. Check the VISA address and try again.");
            }
            finally
            {
                Cursor.Current = Cursors.Default;
            }
        }

        private void btnSetAll_Click(object sender, EventArgs e)
        {
            Cursor.Current = Cursors.WaitCursor;

            // Set each switch
            sc.SetSwitch(1, (int)numSw1.Value);
            sc.SetSwitch(2, (int)numSw2.Value);
            sc.SetSwitch(3, (int)numSw3.Value);
            sc.SetSwitch(4, (int)numSw4.Value);

            // Set each open collector
            sc.SetOpenCollector(1, chkOC1.Checked);
            sc.SetOpenCollector(2, chkOC2.Checked);
            sc.SetOpenCollector(3, chkOC3.Checked);
            sc.SetOpenCollector(4, chkOC4.Checked);

            // set the 12V trigger
            sc.Set12V(chk12V.Checked);

            Cursor.Current = Cursors.Default;
        }

        private void Form1_FormClosing(object sender, FormClosingEventArgs e)
        {
            try
            {
                // Close the session to the SC1000
                sc.Close();
            }
            catch { }
        }

    }
}
